#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_IS_ORD_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_IS_ORD_HPP_INCLUDED

#include <boost/simd/predicates/include/functions/is_ord.hpp>

#endif
